@@ -53,7 +53,7 @@ class Pipeline(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["PipelineProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[PipelineProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
             ) -> None:
                 ...
@@ -107,7 +107,7 @@ class PipelineProps:
             def stub(
                 *,
                 name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
-                notify_config: typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.Union["RosPipeline.NotifyConfigProperty", typing.Dict[str, typing.Any]]]] = None,
+                notify_config: typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.Union[RosPipeline.NotifyConfigProperty, typing.Dict[str, typing.Any]]]] = None,
                 role: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
                 speed: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
                 speed_level: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]] = None,
@@ -243,7 +243,7 @@ class RosPipeline(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["RosPipelineProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[RosPipelineProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: builtins.bool,
             ) -> None:
                 ...
@@ -345,7 +345,7 @@ class RosPipeline(
     ) -> None:
         if __debug__:
             def stub(
-                value: typing.Optional[typing.Union[ros_cdk_core.IResolvable, "RosPipeline.NotifyConfigProperty"]],
+                value: typing.Optional[typing.Union[ros_cdk_core.IResolvable, RosPipeline.NotifyConfigProperty]],
             ) -> None:
                 ...
             type_hints = typing.get_type_hints(stub)
